==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebTreeSelectionOptionsEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTreeSelectionOptionsEventDetailDescriptionMetadata } from "./WebTreeSelectionOptionsEventDetailDescriptionMetadata";
import { WebTreeSelectionOptionsEventArgsDescription } from "./WebTreeSelectionOptionsEventArgsDescription";
/**
 * @hidden
 */
var WebTreeSelectionOptionsEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebTreeSelectionOptionsEventArgsDescriptionMetadata, _super);
    function WebTreeSelectionOptionsEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebTreeSelectionOptionsEventArgsDescriptionMetadata.b = function (a) {
        if (WebTreeSelectionOptionsEventArgsDescriptionMetadata.a == null) {
            WebTreeSelectionOptionsEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebTreeSelectionOptionsEventArgsDescriptionMetadata.c(WebTreeSelectionOptionsEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebTreeSelectionOptionsEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebTreeSelectionOptionsEventArgsDescriptionMetadata.a);
        WebTreeSelectionOptionsEventDetailDescriptionMetadata.d(a);
    };
    WebTreeSelectionOptionsEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:TreeSelectionOptionsEventArgs");
        a.item("Detail", "ExportedType:WebTreeSelectionOptionsEventDetail");
    };
    WebTreeSelectionOptionsEventArgsDescriptionMetadata.d = function (a) {
        WebTreeSelectionOptionsEventArgsDescriptionMetadata.b(a);
        a.aa("WebTreeSelectionOptionsEventArgs", function () { return new WebTreeSelectionOptionsEventArgsDescription(); });
        a.z("WebTreeSelectionOptionsEventArgs", WebTreeSelectionOptionsEventArgsDescriptionMetadata.a);
    };
    WebTreeSelectionOptionsEventArgsDescriptionMetadata.$t = markType(WebTreeSelectionOptionsEventArgsDescriptionMetadata, 'WebTreeSelectionOptionsEventArgsDescriptionMetadata');
    WebTreeSelectionOptionsEventArgsDescriptionMetadata.a = null;
    return WebTreeSelectionOptionsEventArgsDescriptionMetadata;
}(Base));
export { WebTreeSelectionOptionsEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebTreeSelectionOptionsEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTreeSelectionOptionsEventDetailDescriptionMetadata } from "./WebTreeSelectionOptionsEventDetailDescriptionMetadata";
import { WebTreeSelectionOptionsEventArgsDescription } from "./WebTreeSelectionOptionsEventArgsDescription";
/**
 * @hidden
 */
var WebTreeSelectionOptionsEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebTreeSelectionOptionsEventArgsDescriptionMetadata, _super);
    function WebTreeSelectionOptionsEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebTreeSelectionOptionsEventArgsDescriptionMetadata.b = function (a) {
        if (WebTreeSelectionOptionsEventArgsDescriptionMetadata.a == null) {
            WebTreeSelectionOptionsEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebTreeSelectionOptionsEventArgsDescriptionMetadata.c(WebTreeSelectionOptionsEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebTreeSelectionOptionsEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebTreeSelectionOptionsEventArgsDescriptionMetadata.a);
        WebTreeSelectionOptionsEventDetailDescriptionMetadata.d(a);
    };
    WebTreeSelectionOptionsEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:TreeSelectionOptionsEventArgs");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("Detail", "ExportedType:WebTreeSelectionOptionsEventDetail");
    };
    WebTreeSelectionOptionsEventArgsDescriptionMetadata.d = function (a) {
        WebTreeSelectionOptionsEventArgsDescriptionMetadata.b(a);
        a.ac("WebTreeSelectionOptionsEventArgs", function () { return new WebTreeSelectionOptionsEventArgsDescription(); });
        a.ab("WebTreeSelectionOptionsEventArgs", WebTreeSelectionOptionsEventArgsDescriptionMetadata.a);
    };
    WebTreeSelectionOptionsEventArgsDescriptionMetadata.$t = markType(WebTreeSelectionOptionsEventArgsDescriptionMetadata, 'WebTreeSelectionOptionsEventArgsDescriptionMetadata');
    WebTreeSelectionOptionsEventArgsDescriptionMetadata.a = null;
    return WebTreeSelectionOptionsEventArgsDescriptionMetadata;
}(Base));
export { WebTreeSelectionOptionsEventArgsDescriptionMetadata };
